@@ -124,15 +124,15 @@ def _delete_edges(graph, *args, **kwds):
     arguments. Edges in the derived edge sequence will be removed.
     Otherwise the first positional argument is considered as follows:
 
+    Deprecation notice: C{delete_edges(None)} has been replaced by
+    C{delete_edges()} - with no arguments - since igraph 0.8.3.
+
       - C{None} - deletes all edges (deprecated since 0.8.3)
       - a single integer - deletes the edge with the given ID
       - a list of integers - deletes the edges denoted by the given IDs
       - a list of 2-tuples - deletes the edges denoted by the given
         source-target vertex pairs. When multiple edges are present
         between a given source-target vertex pair, only one is removed.
-
-    @deprecated: C{delete_edges(None)} has been replaced by
-    C{delete_edges()} - with no arguments - since igraph 0.8.3.
     """
     if len(args) == 0 and len(kwds) == 0:
         return GraphBase.delete_edges(graph)
